Function whichs adds another mapping to the current list of extramappings
in the madrat configuration (see setConfig) and stores
the mapping in the mapping folder as well as output folder.
Arguments
- filename
The name of the the region mapping that should added including file ending (e.g. "regionmappingREMIND.csv"). Supported formats are currently ".csv" and ".rds".
- mapping
Mapping provided as data.frame, or NULL. If a mapping is provided the data will be written in the mapping file of the given file (potentially replacing existing data). If NULL the mapping from the given file is used.
See also
Other mapping:
toolConvertMapping(),
toolGetMapping()