| cacheCopy | R Documentation |
Copy cache files which were used for a given preprocessing.
cacheCopy(file, target = NULL, filter = NULL)
file |
Path to a log file or content of a log as character vector. |
target |
Folder to which the files should be copied. If NULL no data is copied. |
filter |
Regular expression to filter the cache files shown in the log file. |
A vector of cache files which match the given log information and filter.
Jan Philipp Dietrich
Other cache management:
cacheCleanup()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.