Example for class of fullX functions. Can be used as template for a new function or for testing the basic functionality
Arguments
- rev
data revision which should be used/produced. Will be converted to
numeric_versionwhen called viaretrieveData.- dev
development suffix to distinguish development versions for the same data revision. This can be useful to distinguish parallel lines of development.
- extra
additional argument which - when changed - does not require a re-computation of the portable unaggegrated collection (puc) file.
setConfig(e.g. for setting the mainfolder if not already set properly).
Examples
if (FALSE) { # \dontrun{
retrieveData("example", rev = "2.1.2", dev = "test", regionmapping = "regionmappingH12.csv")
} # }