getLinkFunction: getLinkFunction

View source: R/getLinkFunction.R

getLinkFunctionR Documentation

getLinkFunction

Description

Returns a function that creates a symlink, hardlink, junction, or copy of files and directories, depending on OS capabilities (usually symlinks are not supported on Windows).

Usage

getLinkFunction()

Value

A function with arguments "from" and "to" which should behave like file.symlink on all platforms.

Author(s)

Pascal Sauer

See Also

Other source redirection: redirectSource()


madrat documentation built on July 2, 2026, 9:09 a.m.