Skip to content

Inter- and extrapolates a historical dataset for a given time period.

Usage

toolFillYears(x, years)

Arguments

x

MAgPIE object to be continued.

years

vector of years as digits or in mag year format

Value

MAgPIE object with completed time dimensionality.

See also

Other temporal processing: toolTimeAverage(), toolTimeSpline()

Author

Kristine Karstens