Support tool for the creation of download functions in cases where a fully automated data download is not an option (e.g. due to a missing API). The function can be used to print a step-by-step guide for the user how to manually retrieve the data and then asks for a (local) path where the data can be copied from.
Usage
toolManualDownload(
instructions,
intro = "Data must be downloaded manually",
request = "Enter full path to the downloaded data:"
)See also
Other source downloading:
metadataGFZ()
Examples
if (FALSE) { # \dontrun{
toolManualDownload(c("Log into website ABC",
"Download the data set XYZ"))
} # }