Selects the countries with the highest values in a magpie object
Arguments
- x
magclass object that shall be used for ranking
- range
the position of the countries in the top X which should be returned.
- years
range of years that shall be summed for ranking. If NULL, the sum of all years is used.
- elements
range of elements that shall be summed for ranking. If NULL, all elements are used.
See also
Other data manipulation:
toolConditionalReplace(),
toolFixWeight(),
toolNAreplace(),
toolOrderCells()
Examples
toolXlargest(magclass::maxample("pop"), range = 1:3)
#> [1] "SAS" "AFR" "CPA"