This function prepares total tau values for use. As the source data already provides all required information this function purely removes not required data and moves xref values to the weighting object which is required for aggregation.
Examples
if (FALSE) { # \dontrun{
calcOutput("TauTotal")
} # }