compareData: compareData

View source: R/compareData.R

compareDataR Documentation

compareData

Description

Compares the content of two data archives and looks for similarities and differences

Usage

compareData(x, y, tolerance = 10^-5, yearLim = NULL)

Arguments

x

Either a tgz file or a folder containing data sets

y

Either a tgz file or a folder containing data sets

tolerance

tolerance level below which differences will get ignored

yearLim

year until when the comparison should be performed. Useful to check if data is identical until a certain year.

Author(s)

Jan Philipp Dietrich, Florian Humpenoeder

See Also

setConfig, calcTauTotal,

Other validation: compareMadratOutputs(), toolCompareStatusLogs()


madrat documentation built on July 2, 2026, 9:09 a.m.