Function which returns the ISO list which is used as default for the input data preparation. It contains the countries to which all source data has to be up- or downscaled to.
Arguments
- type
Determines what countries should be returned. "all" returns all countries, "important" returns all countries which are above the population threshold set in the configuration and "dispensable" returns all countries which are below the threshold.
- threshold
Population threshold in million capita which determines whether the country is put into the "important" or "dispensable" class (default = 1 mio. people)
Note
Please always use this function instead of directly referring to the data object as the format in this data list might change in the future!
See also
Other country tools:
toolCountry2isocode(),
toolCountryFill(),
toolFillWithRegionAvg(),
toolISOhistorical()