Skip to content

Returns a function that creates a symlink, hardlink, junction, or copy of files and directories, depending on OS capabilities (usually symlinks are not supported on Windows).

Usage

getLinkFunction()

Value

A function with arguments "from" and "to" which should behave like file.symlink on all platforms.

See also

Other source redirection: redirectSource()

Author

Pascal Sauer