View source: R/getLinkFunction.R
| getLinkFunction | R Documentation |
Returns a function that creates a symlink, hardlink, junction, or copy of files and directories, depending on OS capabilities (usually symlinks are not supported on Windows).
getLinkFunction()
A function with arguments "from" and "to" which should behave like file.symlink on all platforms.
Pascal Sauer
Other source redirection:
redirectSource()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.