Collects and returns detailed information about the currently loaded network of madrat functions.
Arguments
- graph
A madrat graph as returned by
getMadratGraph. Will be created withgetMadratGraphif not provided.- cutoff
Integer introducing a cutoff of items to be returned for outputs which can become quite verbose.
- extended
Will add additional outputs which has been removed from standard output due to limited usefulness.
- ...
Additional arguments for
getMadratGraphin case that no graph is provided (otherwise ignored)
See also
getCalculations, getMadratGraph
Other dependency graph:
getDependencies(),
getMadratGraph(),
visualizeDependencies()