Attaches the madrat functions of a package to the currently active madrat universe or detaches it again from it.
See also
Other madrat configuration:
getConfig(),
setConfig()
Attaches the madrat functions of a package to the currently active madrat universe or detaches it again from it.
Other madrat configuration:
getConfig(),
setConfig()