Creates a puc-file ("portable unaggregated collection") for a collection that was already
computed via retrieveData (e.g. with puc = FALSE, or where a puc could
not be created at the time, for example due to strict mode). This makes it possible to
create a puc-file for an existing archive without having to rerun the underlying
calculations.
Arguments
- archive
path to a tgz-file as created by
retrieveData- pucName
(Optional) name (without the
.pucextension) the puc-file should be given. Only needed for archives created beforeretrieveDatastarted recording this name inconfig.rds.
Note
This only works as long as the madrat cache files that were used to compute the
archive are still available on this machine, as the archive itself only contains the
aggregated collection, not the underlying cache files. If some of these cache files are
missing pucCreate will fail with an error naming them.
See also
Other aggregation:
pucAggregate(),
toolAggregate()