Delete stored madrat messages from the madrat environment. The madrat environment behaves similar like global options, except that 1) messages will also be stored in cache files and restored when a cache file is being loaded and 2) messages are always stored in lists with messages split by function calls where the message was triggered.
See also
putMadratMessage, getMadratMessage
Other madrat messages:
getMadratMessage(),
putMadratMessage(),
vcat()
Examples
putMadratMessage("test", "This is a toast", fname = "readTau")
getMadratMessage("test", fname = "calcTauTotal")
#> $readTau
#> [1] "This is a toast"
#>
resetMadratMessages("test")