View source: R/toolAggregate.R
| toolExpandRel | R Documentation |
Expands aggregation matrix to full items for matrices that only contain subdim items in from/to.
toolExpandRel(rel, x, dim)
rel |
The aggregation matrix with subdim items |
x |
The data to be aggregated already sub-set in case of a partial relation |
dim |
The (sub-)dim to be aggregated |
Works by first generating all possible from/to items, then sub-setting to only the ones that are actually valid, i.e. from-items that appear in the original data, and to-items that only contain sub-items that also occur in the from-items, so an aggregated item should only contain sub-items that were also present in all from-items it was aggregated from.
An expanded aggregation matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.