This function is a support function for the selection of a subtype in a readX function. In addition to the subtype selection it also performs some consistency checks.
See also
Other subtype handling:
toolSplitSubtype()
Examples
files <- c(protection="protection.csv",
production="production.csv",
extent="forest_extent.csv")
toolSubtypeSelect("extent",files)
#> [1] "forest_extent.csv"