withMadratLogging: Tool: withMadratLogging

View source: R/withMadratLogging.R

withMadratLoggingR Documentation

Tool: withMadratLogging

Description

Function will activate madrat logging facilities for all code provided to this function. This means that message, warning and stop calls will also report to the madrat log output

Usage

withMadratLogging(expr, logOnly = TRUE)

Arguments

expr

expression to be evaluated.

logOnly

passed to vcat, determines if warning/error is thrown after logging

Author(s)

Jan Philipp Dietrich

See Also

vcat

Examples

## Not run: 
madrat:::withMadratLogging(message("Hello world!"))

## End(Not run)


madrat documentation built on July 2, 2026, 9:09 a.m.